@@ -25,9 +25,9 @@
 #include "kopetecontactlist.h"
 #include "kopetepassword.h"
 
-#include <kaction.h>
+#include <QAction>
 #include <kactionmenu.h>
-#include <kmenu.h>
+#include <QMenu>
 #include <klocale.h>
 #include <kconfigbase.h>
 #include <kinputdialog.h>
@@ -106,7 +106,6 @@ void MeanwhileAccount::connectWithPassword(const QString &password)
 
    //     void connect(QString host, int port, QString account, QString password);
 
-
     if (!m_session->isConnected() && !m_session->isConnecting())
         m_session->connect(password);
 
@@ -139,7 +138,7 @@ void MeanwhileAccount::fillActionMenu( KActionMenu *actionMenu )
 	actionMenu->menu()->addSeparator();
 
 #if 0
-    actionMenu->insert(new KAction(i18n("&Change Status Message"), QString(), 0,
+    actionMenu->insert(new QAction(i18n("&Change Status Message"), QString(), 0,
                 this, SLOT(meanwhileChangeStatus()), this,
                 "meanwhileChangeStatus"));
     //infoPlugin->addCustomMenus(theMenu);
@@ -284,4 +283,3 @@ MeanwhileSession *MeanwhileAccount::session()
     return m_session;
 }
 
-#include "meanwhileaccount.moc"
